@@ -8,19 +8,6 @@ more details on pdb++ features.
 
 from __future__ import print_function
 
-def get_version():
-    try:
-        import pkg_resources
-        dist = pkg_resources.get_distribution('pdbpp')
-        return dist.version
-    except Exception:
-        pass
-
-
-__version__ = get_version()
-__author__ = 'Antonio Cuni <anto.cuni@gmail.com>'
-__url__ = 'http://github.com/antocuni/pdb'
-
 import sys
 import os.path
 import inspect
@@ -34,6 +21,10 @@ import re
 from fancycompleter import Completer, ConfigurableClass, Color
 import fancycompleter
 
+__author__ = 'Antonio Cuni <anto.cuni@gmail.com>'
+__url__ = 'http://github.com/antocuni/pdb'
+__version__ = fancycompleter.LazyVersion('pdbpp')
+
 try:
     from inspect import signature  # Python >= 3.3
 except ImportError:
@@ -635,8 +626,8 @@ Frames can marked as hidden in the following ways:
         #
         # inside the original do_debug, there is a call to the global "Pdb" to
         # instantiate the recursive debugger: we want to intercept this call
-        # and instantiate *our* Pdb, passing the our custom config. So, we
-        # dynamically rebind the globals
+        # and instantiate *our* Pdb, passing our custom config. Therefore we
+        # dynamically rebind the globals.
         #
         def new_pdb_with_config(*args):
             kwds = dict(Config=self.ConfigFactory)
